@@ -109,6 +109,7 @@ from .blosc2_ext import (
     GLOBAL_REGISTERED_CODECS_STOP,
     MAX_BLOCKSIZE,
     MAX_BUFFERSIZE,
+    MAX_DIM,
     MAX_OVERHEAD,
     MAX_TYPESIZE,
     MIN_HEADER_LENGTH,
@@ -237,6 +238,8 @@ from .ndarray import (
     sort,
     reshape,
     copy,
+    concatenate,
+    expand_dims,
     empty,
     frombuffer,
     fromiter,
@@ -251,6 +254,7 @@ from .ndarray import (
     permute_dims,
     transpose,
     matrix_transpose,
+    stack,
 )
 
 from .c2array import c2context, C2Array, URLPath
